@@ -4,6 +4,7 @@ import (
 	"flag"
 	"fmt"
 	"os"
+	"regexp"
 	"runtime"
 	"strings"
 
@@ -90,8 +91,8 @@ func main() {
 	defer fuzzplayground.Cleanup()
 	server := fuzzplayground.GetPlaygroundServer()
 	defer func() {
-         _ = server.Close()
-       }()
+		_ = server.Close()
+	}()
 	go func() {
 		if err := server.Start("localhost:8082"); err != nil {
 			if !strings.Contains(err.Error(), "Server closed") {
@@ -210,7 +211,7 @@ func execute(testCase testutils.TestCase, templatePath string) (string, error) {
 }
 
 func expectResultsCount(results []string, expectedNumbers ...int) error {
-	results = filterHeadlessLogs(results)
+	results = filterLines(results)
 	match := sliceutil.Contains(expectedNumbers, len(results))
 	if !match {
 		return fmt.Errorf("incorrect number of results: %d (actual) vs %v (expected) \nResults:\n\t%s\n", len(results), expectedNumbers, strings.Join(results, "\n\t")) // nolint:all
@@ -224,6 +225,13 @@ func normalizeSplit(str string) []string {
 	})
 }
 
+// filterLines applies all filtering functions to the results
+func filterLines(results []string) []string {
+	results = filterHeadlessLogs(results)
+	results = filterUnsignedTemplatesWarnings(results)
+	return results
+}
+
 // if chromium is not installed go-rod installs it in .cache directory
 // this function filters out the logs from download and installation
 func filterHeadlessLogs(results []string) []string {
@@ -237,3 +245,16 @@ func filterHeadlessLogs(results []string) []string {
 	}
 	return filtered
 }
+
+// filterUnsignedTemplatesWarnings filters out warning messages about unsigned templates
+func filterUnsignedTemplatesWarnings(results []string) []string {
+	filtered := []string{}
+	unsignedTemplatesRegex := regexp.MustCompile(`Loading \d+ unsigned templates for scan\. Use with caution\.`)
+	for _, result := range results {
+		if unsignedTemplatesRegex.MatchString(result) {
+			continue
+		}
+		filtered = append(filtered, result)
+	}
+	return filtered
+}
