@@ -19,7 +19,7 @@ import (
 	"github.com/projectdiscovery/retryablehttp-go"
 	pdcpauth "github.com/projectdiscovery/utils/auth/pdcp"
 	"github.com/projectdiscovery/utils/env"
-	errorutil "github.com/projectdiscovery/utils/errors"
+	"github.com/projectdiscovery/utils/errkit"
 	unitutils "github.com/projectdiscovery/utils/unit"
 	updateutils "github.com/projectdiscovery/utils/update"
 	urlutil "github.com/projectdiscovery/utils/url"
@@ -55,10 +55,11 @@ type UploadWriter struct {
 	scanName  string
 	counter   atomic.Int32
 	TeamID    string
+	Logger    *gologger.Logger
 }
 
 // NewUploadWriter creates a new upload writer
-func NewUploadWriter(ctx context.Context, creds *pdcpauth.PDCPCredentials) (*UploadWriter, error) {
+func NewUploadWriter(ctx context.Context, logger *gologger.Logger, creds *pdcpauth.PDCPCredentials) (*UploadWriter, error) {
 	if creds == nil {
 		return nil, fmt.Errorf("no credentials provided")
 	}
@@ -66,6 +67,7 @@ func NewUploadWriter(ctx context.Context, creds *pdcpauth.PDCPCredentials) (*Upl
 		creds:  creds,
 		done:   make(chan struct{}, 1),
 		TeamID: NoneTeamID,
+		Logger: logger,
 	}
 	var err error
 	reader, writer := io.Pipe()
@@ -75,11 +77,11 @@ func NewUploadWriter(ctx context.Context, creds *pdcpauth.PDCPCredentials) (*Upl
 		output.WithJson(true, true),
 	)
 	if err != nil {
-		return nil, errorutil.NewWithErr(err).Msgf("could not create output writer")
+		return nil, errkit.Append(errkit.New("could not create output writer"), err)
 	}
 	tmp, err := urlutil.Parse(creds.Server)
 	if err != nil {
-		return nil, errorutil.NewWithErr(err).Msgf("could not parse server url")
+		return nil, errkit.Append(errkit.New("could not parse server url"), err)
 	}
 	tmp.Path = uploadEndpoint
 	tmp.Update()
@@ -128,8 +130,8 @@ func (u *UploadWriter) autoCommit(ctx context.Context, r *io.PipeReader) {
 	// continuously read from the reader and send to channel
 	go func() {
 		defer func() {
-          _ = r.Close()
-        }()
+			_ = r.Close()
+		}()
 		defer close(ch)
 		for {
 			data, err := reader.ReadString('\n')
@@ -147,9 +149,9 @@ func (u *UploadWriter) autoCommit(ctx context.Context, r *io.PipeReader) {
 		close(u.done)
 		// if no scanid is generated no results were uploaded
 		if u.scanID == "" {
-			gologger.Verbose().Msgf("Scan results upload to cloud skipped, no results found to upload")
+			u.Logger.Verbose().Msgf("Scan results upload to cloud skipped, no results found to upload")
 		} else {
-			gologger.Info().Msgf("%v Scan results uploaded to cloud, you can view scan results at %v", u.counter.Load(), getScanDashBoardURL(u.scanID, u.TeamID))
+			u.Logger.Info().Msgf("%v Scan results uploaded to cloud, you can view scan results at %v", u.counter.Load(), getScanDashBoardURL(u.scanID, u.TeamID))
 		}
 	}()
 	// temporary buffer to store the results
@@ -162,7 +164,7 @@ func (u *UploadWriter) autoCommit(ctx context.Context, r *io.PipeReader) {
 			// flush before exit
 			if buff.Len() > 0 {
 				if err := u.uploadChunk(buff); err != nil {
-					gologger.Error().Msgf("Failed to upload scan results on cloud: %v", err)
+					u.Logger.Error().Msgf("Failed to upload scan results on cloud: %v", err)
 				}
 			}
 			return
@@ -170,14 +172,14 @@ func (u *UploadWriter) autoCommit(ctx context.Context, r *io.PipeReader) {
 			// flush the buffer
 			if buff.Len() > 0 {
 				if err := u.uploadChunk(buff); err != nil {
-					gologger.Error().Msgf("Failed to upload scan results on cloud: %v", err)
+					u.Logger.Error().Msgf("Failed to upload scan results on cloud: %v", err)
 				}
 			}
 		case line, ok := <-ch:
 			if !ok {
 				if buff.Len() > 0 {
 					if err := u.uploadChunk(buff); err != nil {
-						gologger.Error().Msgf("Failed to upload scan results on cloud: %v", err)
+						u.Logger.Error().Msgf("Failed to upload scan results on cloud: %v", err)
 					}
 				}
 				return
@@ -185,7 +187,7 @@ func (u *UploadWriter) autoCommit(ctx context.Context, r *io.PipeReader) {
 			if buff.Len()+len(line) > MaxChunkSize {
 				// flush existing buffer
 				if err := u.uploadChunk(buff); err != nil {
-					gologger.Error().Msgf("Failed to upload scan results on cloud: %v", err)
+					u.Logger.Error().Msgf("Failed to upload scan results on cloud: %v", err)
 				}
 			} else {
 				buff.WriteString(line)
@@ -197,37 +199,37 @@ func (u *UploadWriter) autoCommit(ctx context.Context, r *io.PipeReader) {
 // uploadChunk uploads a chunk of data to the server
 func (u *UploadWriter) uploadChunk(buff *bytes.Buffer) error {
 	if err := u.upload(buff.Bytes()); err != nil {
-		return errorutil.NewWithErr(err).Msgf("could not upload chunk")
+		return errkit.Append(errkit.New("could not upload chunk"), err)
 	}
 	// if successful, reset the buffer
 	buff.Reset()
 	// log in verbose mode
-	gologger.Warning().Msgf("Uploaded results chunk, you can view scan results at %v", getScanDashBoardURL(u.scanID, u.TeamID))
+	u.Logger.Warning().Msgf("Uploaded results chunk, you can view scan results at %v", getScanDashBoardURL(u.scanID, u.TeamID))
 	return nil
 }
 
 func (u *UploadWriter) upload(data []byte) error {
 	req, err := u.getRequest(data)
 	if err != nil {
-		return errorutil.NewWithErr(err).Msgf("could not create upload request")
+		return errkit.Append(errkit.New("could not create upload request"), err)
 	}
 	resp, err := u.client.Do(req)
 	if err != nil {
-		return errorutil.NewWithErr(err).Msgf("could not upload results")
+		return errkit.Append(errkit.New("could not upload results"), err)
 	}
 	defer func() {
-         _ = resp.Body.Close()
-       }()
+		_ = resp.Body.Close()
+	}()
 	bin, err := io.ReadAll(resp.Body)
 	if err != nil {
-		return errorutil.NewWithErr(err).Msgf("could not get id from response")
+		return errkit.Append(errkit.New("could not get id from response"), err)
 	}
 	if resp.StatusCode != http.StatusOK {
 		return fmt.Errorf("could not upload results got status code %v on %v", resp.StatusCode, resp.Request.URL.String())
 	}
 	var uploadResp uploadResponse
 	if err := json.Unmarshal(bin, &uploadResp); err != nil {
-		return errorutil.NewWithErr(err).Msgf("could not unmarshal response got %v", string(bin))
+		return errkit.Append(errkit.New(fmt.Sprintf("could not unmarshal response got %v", string(bin))), err)
 	}
 	if uploadResp.ID != "" && u.scanID == "" {
 		u.scanID = uploadResp.ID
@@ -252,7 +254,7 @@ func (u *UploadWriter) getRequest(bin []byte) (*retryablehttp.Request, error) {
 	}
 	req, err := retryablehttp.NewRequest(method, url, bytes.NewReader(bin))
 	if err != nil {
-		return nil, errorutil.NewWithErr(err).Msgf("could not create cloud upload request")
+		return nil, errkit.Append(errkit.New("could not create cloud upload request"), err)
 	}
 	// add pdtm meta params
 	req.Params.Merge(updateutils.GetpdtmParams(config.Version))
@@ -260,7 +262,7 @@ func (u *UploadWriter) getRequest(bin []byte) (*retryablehttp.Request, error) {
 	if u.scanName != "" && req.Path == uploadEndpoint {
 		req.Params.Add("name", u.scanName)
 	}
-	req.URL.Update()
+	req.Update()
 
 	req.Header.Set(pdcpauth.ApiKeyHeaderName, u.creds.APIKey)
 	if u.TeamID != NoneTeamID && u.TeamID != "" {
