@@ -1,6 +1,8 @@
 package compiler
 
 import (
+	"sync"
+
 	"github.com/projectdiscovery/nuclei/v3/pkg/types"
 )
 
@@ -9,10 +11,13 @@ import (
 var (
 	PoolingJsVmConcurrency  = 100
 	NonPoolingVMConcurrency = 20
+	m                       sync.Mutex
 )
 
 // Init initializes the javascript protocol
 func Init(opts *types.Options) error {
+	m.Lock()
+	defer m.Unlock()
 
 	if opts.JsConcurrency < 100 {
 		// 100 is reasonable default
