@@ -36,8 +36,9 @@ type (
 // const client = new mssql.MSSQLClient;
 // const connected = client.Connect('acme.com', 1433, 'username', 'password');
 // ```
-func (c *MSSQLClient) Connect(host string, port int, username, password string) (bool, error) {
-	return memoizedconnect(host, port, username, password, "master")
+func (c *MSSQLClient) Connect(ctx context.Context, host string, port int, username, password string) (bool, error) {
+	executionId := ctx.Value("executionId").(string)
+	return memoizedconnect(executionId, host, port, username, password, "master")
 }
 
 // ConnectWithDB connects to MS SQL database using given credentials and database name.
@@ -50,18 +51,19 @@ func (c *MSSQLClient) Connect(host string, port int, username, password string)
 // const client = new mssql.MSSQLClient;
 // const connected = client.ConnectWithDB('acme.com', 1433, 'username', 'password', 'master');
 // ```
-func (c *MSSQLClient) ConnectWithDB(host string, port int, username, password, dbName string) (bool, error) {
-	return memoizedconnect(host, port, username, password, dbName)
+func (c *MSSQLClient) ConnectWithDB(ctx context.Context, host string, port int, username, password, dbName string) (bool, error) {
+	executionId := ctx.Value("executionId").(string)
+	return memoizedconnect(executionId, host, port, username, password, dbName)
 }
 
 // @memo
-func connect(host string, port int, username string, password string, dbName string) (bool, error) {
+func connect(executionId string, host string, port int, username string, password string, dbName string) (bool, error) {
 	if host == "" || port <= 0 {
 		return false, fmt.Errorf("invalid host or port")
 	}
-	if !protocolstate.IsHostAllowed(host) {
+	if !protocolstate.IsHostAllowed(executionId, host) {
 		// host is not valid according to network policy
-		return false, protocolstate.ErrHostDenied.Msgf(host)
+		return false, protocolstate.ErrHostDenied(host)
 	}
 
 	target := net.JoinHostPort(host, fmt.Sprintf("%d", port))
@@ -77,8 +79,8 @@ func connect(host string, port int, username string, password string, dbName str
 		return false, err
 	}
 	defer func() {
-         _ = db.Close()
-       }()
+		_ = db.Close()
+	}()
 
 	_, err = db.Exec("select 1")
 	if err != nil {
@@ -107,24 +109,30 @@ func connect(host string, port int, username string, password string, dbName str
 // const mssql = require('nuclei/mssql');
 // const isMssql = mssql.IsMssql('acme.com', 1433);
 // ```
-func (c *MSSQLClient) IsMssql(host string, port int) (bool, error) {
-	return memoizedisMssql(host, port)
+func (c *MSSQLClient) IsMssql(ctx context.Context, host string, port int) (bool, error) {
+	executionId := ctx.Value("executionId").(string)
+	return memoizedisMssql(executionId, host, port)
 }
 
 // @memo
-func isMssql(host string, port int) (bool, error) {
-	if !protocolstate.IsHostAllowed(host) {
+func isMssql(executionId string, host string, port int) (bool, error) {
+	if !protocolstate.IsHostAllowed(executionId, host) {
 		// host is not valid according to network policy
-		return false, protocolstate.ErrHostDenied.Msgf(host)
+		return false, protocolstate.ErrHostDenied(host)
 	}
 
-	conn, err := protocolstate.Dialer.Dial(context.TODO(), "tcp", net.JoinHostPort(host, fmt.Sprintf("%d", port)))
+	dialer := protocolstate.GetDialersWithId(executionId)
+	if dialer == nil {
+		return false, fmt.Errorf("dialers not initialized for %s", executionId)
+	}
+
+	conn, err := dialer.Fastdialer.Dial(context.TODO(), "tcp", net.JoinHostPort(host, fmt.Sprintf("%d", port)))
 	if err != nil {
 		return false, err
 	}
 	defer func() {
-         _ = conn.Close()
-       }()
+		_ = conn.Close()
+	}()
 
 	data, check, err := mssql.DetectMSSQL(conn, 5*time.Second)
 	if check && err != nil {
@@ -147,18 +155,19 @@ func isMssql(host string, port int) (bool, error) {
 // const result = client.ExecuteQuery('acme.com', 1433, 'username', 'password', 'master', 'SELECT @@version');
 // log(to_json(result));
 // ```
-func (c *MSSQLClient) ExecuteQuery(host string, port int, username, password, dbName, query string) (*utils.SQLResult, error) {
+func (c *MSSQLClient) ExecuteQuery(ctx context.Context, host string, port int, username, password, dbName, query string) (*utils.SQLResult, error) {
+	executionId := ctx.Value("executionId").(string)
 	if host == "" || port <= 0 {
 		return nil, fmt.Errorf("invalid host or port")
 	}
-	if !protocolstate.IsHostAllowed(host) {
+	if !protocolstate.IsHostAllowed(executionId, host) {
 		// host is not valid according to network policy
-		return nil, protocolstate.ErrHostDenied.Msgf(host)
+		return nil, protocolstate.ErrHostDenied(host)
 	}
 
 	target := net.JoinHostPort(host, fmt.Sprintf("%d", port))
 
-	ok, err := c.IsMssql(host, port)
+	ok, err := c.IsMssql(ctx, host, port)
 	if err != nil {
 		return nil, err
 	}
@@ -177,8 +186,8 @@ func (c *MSSQLClient) ExecuteQuery(host string, port int, username, password, db
 		return nil, err
 	}
 	defer func() {
-         _ = db.Close()
-       }()
+		_ = db.Close()
+	}()
 
 	db.SetMaxOpenConns(1)
 	db.SetMaxIdleConns(0)
