@@ -8,11 +8,11 @@ import (
 	"github.com/projectdiscovery/nuclei/v3/pkg/protocols/common/protocolstate"
 )
 
-func memoizedisRDP(host string, port int) (IsRDPResponse, error) {
+func memoizedisRDP(executionId string, host string, port int) (IsRDPResponse, error) {
 	hash := "isRDP" + ":" + fmt.Sprint(host) + ":" + fmt.Sprint(port)
 
 	v, err, _ := protocolstate.Memoizer.Do(hash, func() (interface{}, error) {
-		return isRDP(host, port)
+		return isRDP(executionId, host, port)
 	})
 	if err != nil {
 		return IsRDPResponse{}, err
@@ -24,11 +24,11 @@ func memoizedisRDP(host string, port int) (IsRDPResponse, error) {
 	return IsRDPResponse{}, errors.New("could not convert cached result")
 }
 
-func memoizedcheckRDPAuth(host string, port int) (CheckRDPAuthResponse, error) {
+func memoizedcheckRDPAuth(executionId string, host string, port int) (CheckRDPAuthResponse, error) {
 	hash := "checkRDPAuth" + ":" + fmt.Sprint(host) + ":" + fmt.Sprint(port)
 
 	v, err, _ := protocolstate.Memoizer.Do(hash, func() (interface{}, error) {
-		return checkRDPAuth(host, port)
+		return checkRDPAuth(executionId, host, port)
 	})
 	if err != nil {
 		return CheckRDPAuthResponse{}, err
