@@ -18,15 +18,16 @@ import (
 // const redis = require('nuclei/redis');
 // const info = redis.GetServerInfo('acme.com', 6379);
 // ```
-func GetServerInfo(host string, port int) (string, error) {
-	return memoizedgetServerInfo(host, port)
+func GetServerInfo(ctx context.Context, host string, port int) (string, error) {
+	executionId := ctx.Value("executionId").(string)
+	return memoizedgetServerInfo(executionId, host, port)
 }
 
 // @memo
-func getServerInfo(host string, port int) (string, error) {
-	if !protocolstate.IsHostAllowed(host) {
+func getServerInfo(executionId string, host string, port int) (string, error) {
+	if !protocolstate.IsHostAllowed(executionId, host) {
 		// host is not valid according to network policy
-		return "", protocolstate.ErrHostDenied.Msgf(host)
+		return "", protocolstate.ErrHostDenied(host)
 	}
 	// create a new client
 	client := redis.NewClient(&redis.Options{
@@ -35,8 +36,8 @@ func getServerInfo(host string, port int) (string, error) {
 		DB:       0,  // use default DB
 	})
 	defer func() {
-         _ = client.Close()
-       }()
+		_ = client.Close()
+	}()
 
 	// Ping the Redis server
 	_, err := client.Ping(context.TODO()).Result()
@@ -59,15 +60,16 @@ func getServerInfo(host string, port int) (string, error) {
 // const redis = require('nuclei/redis');
 // const connected = redis.Connect('acme.com', 6379, 'password');
 // ```
-func Connect(host string, port int, password string) (bool, error) {
-	return memoizedconnect(host, port, password)
+func Connect(ctx context.Context, host string, port int, password string) (bool, error) {
+	executionId := ctx.Value("executionId").(string)
+	return memoizedconnect(executionId, host, port, password)
 }
 
 // @memo
-func connect(host string, port int, password string) (bool, error) {
-	if !protocolstate.IsHostAllowed(host) {
+func connect(executionId string, host string, port int, password string) (bool, error) {
+	if !protocolstate.IsHostAllowed(executionId, host) {
 		// host is not valid according to network policy
-		return false, protocolstate.ErrHostDenied.Msgf(host)
+		return false, protocolstate.ErrHostDenied(host)
 	}
 	// create a new client
 	client := redis.NewClient(&redis.Options{
@@ -76,8 +78,8 @@ func connect(host string, port int, password string) (bool, error) {
 		DB:       0,        // use default DB
 	})
 	defer func() {
-         _ = client.Close()
-       }()
+		_ = client.Close()
+	}()
 
 	_, err := client.Ping(context.TODO()).Result()
 	if err != nil {
@@ -98,15 +100,16 @@ func connect(host string, port int, password string) (bool, error) {
 // const redis = require('nuclei/redis');
 // const info = redis.GetServerInfoAuth('acme.com', 6379, 'password');
 // ```
-func GetServerInfoAuth(host string, port int, password string) (string, error) {
-	return memoizedgetServerInfoAuth(host, port, password)
+func GetServerInfoAuth(ctx context.Context, host string, port int, password string) (string, error) {
+	executionId := ctx.Value("executionId").(string)
+	return memoizedgetServerInfoAuth(executionId, host, port, password)
 }
 
 // @memo
-func getServerInfoAuth(host string, port int, password string) (string, error) {
-	if !protocolstate.IsHostAllowed(host) {
+func getServerInfoAuth(executionId string, host string, port int, password string) (string, error) {
+	if !protocolstate.IsHostAllowed(executionId, host) {
 		// host is not valid according to network policy
-		return "", protocolstate.ErrHostDenied.Msgf(host)
+		return "", protocolstate.ErrHostDenied(host)
 	}
 	// create a new client
 	client := redis.NewClient(&redis.Options{
@@ -115,8 +118,8 @@ func getServerInfoAuth(host string, port int, password string) (string, error) {
 		DB:       0,        // use default DB
 	})
 	defer func() {
-         _ = client.Close()
-       }()
+		_ = client.Close()
+	}()
 
 	// Ping the Redis server
 	_, err := client.Ping(context.TODO()).Result()
@@ -139,21 +142,27 @@ func getServerInfoAuth(host string, port int, password string) (string, error) {
 // const redis = require('nuclei/redis');
 // const isAuthenticated = redis.IsAuthenticated('acme.com', 6379);
 // ```
-func IsAuthenticated(host string, port int) (bool, error) {
-	return memoizedisAuthenticated(host, port)
+func IsAuthenticated(ctx context.Context, host string, port int) (bool, error) {
+	executionId := ctx.Value("executionId").(string)
+	return memoizedisAuthenticated(executionId, host, port)
 }
 
 // @memo
-func isAuthenticated(host string, port int) (bool, error) {
+func isAuthenticated(executionId string, host string, port int) (bool, error) {
 	plugin := pluginsredis.REDISPlugin{}
 	timeout := 5 * time.Second
-	conn, err := protocolstate.Dialer.Dial(context.TODO(), "tcp", fmt.Sprintf("%s:%d", host, port))
+	dialer := protocolstate.GetDialersWithId(executionId)
+	if dialer == nil {
+		return false, fmt.Errorf("dialers not initialized for %s", executionId)
+	}
+
+	conn, err := dialer.Fastdialer.Dial(context.TODO(), "tcp", fmt.Sprintf("%s:%d", host, port))
 	if err != nil {
 		return false, err
 	}
 	defer func() {
-         _ = conn.Close()
-       }()
+		_ = conn.Close()
+	}()
 
 	_, err = plugin.Run(conn, timeout, plugins.Target{Host: host})
 	if err != nil {
@@ -168,10 +177,11 @@ func isAuthenticated(host string, port int) (bool, error) {
 // const redis = require('nuclei/redis');
 // const result = redis.RunLuaScript('acme.com', 6379, 'password', 'return redis.call("get", KEYS[1])');
 // ```
-func RunLuaScript(host string, port int, password string, script string) (interface{}, error) {
-	if !protocolstate.IsHostAllowed(host) {
+func RunLuaScript(ctx context.Context, host string, port int, password string, script string) (interface{}, error) {
+	executionId := ctx.Value("executionId").(string)
+	if !protocolstate.IsHostAllowed(executionId, host) {
 		// host is not valid according to network policy
-		return false, protocolstate.ErrHostDenied.Msgf(host)
+		return false, protocolstate.ErrHostDenied(host)
 	}
 	// create a new client
 	client := redis.NewClient(&redis.Options{
@@ -180,8 +190,8 @@ func RunLuaScript(host string, port int, password string, script string) (interf
 		DB:       0, // use default DB
 	})
 	defer func() {
-         _ = client.Close()
-       }()
+		_ = client.Close()
+	}()
 
 	// Ping the Redis server
 	_, err := client.Ping(context.TODO()).Result()
