@@ -8,11 +8,11 @@ import (
 	"github.com/projectdiscovery/nuclei/v3/pkg/protocols/common/protocolstate"
 )
 
-func memoizeddetectSMBGhost(host string, port int) (bool, error) {
+func memoizeddetectSMBGhost(executionId string, host string, port int) (bool, error) {
 	hash := "detectSMBGhost" + ":" + fmt.Sprint(host) + ":" + fmt.Sprint(port)
 
 	v, err, _ := protocolstate.Memoizer.Do(hash, func() (interface{}, error) {
-		return detectSMBGhost(host, port)
+		return detectSMBGhost(executionId, host, port)
 	})
 	if err != nil {
 		return false, err
