@@ -2,6 +2,7 @@ package telnet
 
 import (
 	"context"
+	"fmt"
 	"net"
 	"strconv"
 	"time"
@@ -33,16 +34,22 @@ type (
 // const isTelnet = telnet.IsTelnet('acme.com', 23);
 // log(toJSON(isTelnet));
 // ```
-func IsTelnet(host string, port int) (IsTelnetResponse, error) {
-	return memoizedisTelnet(host, port)
+func IsTelnet(ctx context.Context, host string, port int) (IsTelnetResponse, error) {
+	executionId := ctx.Value("executionId").(string)
+	return memoizedisTelnet(executionId, host, port)
 }
 
 // @memo
-func isTelnet(host string, port int) (IsTelnetResponse, error) {
+func isTelnet(executionId string, host string, port int) (IsTelnetResponse, error) {
 	resp := IsTelnetResponse{}
 
 	timeout := 5 * time.Second
-	conn, err := protocolstate.Dialer.Dial(context.TODO(), "tcp", net.JoinHostPort(host, strconv.Itoa(port)))
+	dialer := protocolstate.GetDialersWithId(executionId)
+	if dialer == nil {
+		return IsTelnetResponse{}, fmt.Errorf("dialers not initialized for %s", executionId)
+	}
+
+	conn, err := dialer.Fastdialer.Dial(context.TODO(), "tcp", net.JoinHostPort(host, strconv.Itoa(port)))
 	if err != nil {
 		return resp, err
 	}
