@@ -6,7 +6,7 @@ import (
 	"strings"
 	"sync"
 
-	"github.com/dop251/goja"
+	"github.com/Mzack9999/goja"
 )
 
 // temporary on demand runtime to throw errors when vm is not available
@@ -42,6 +42,14 @@ func (j *NucleiJS) runtime() *goja.Runtime {
 	return j.vm
 }
 
+func (j *NucleiJS) ExecutionId() string {
+	executionId, ok := j.vm.GetContextValue("executionId")
+	if !ok {
+		return ""
+	}
+	return executionId.(string)
+}
+
 // see: https://arc.net/l/quote/wpenftpc for throwing docs
 
 // ThrowError throws an error in goja runtime if is not nil
