@@ -4,6 +4,7 @@ package generators
 
 import (
 	"github.com/pkg/errors"
+	"maps"
 
 	"github.com/projectdiscovery/nuclei/v3/pkg/catalog"
 	"github.com/projectdiscovery/nuclei/v3/pkg/types"
@@ -32,9 +33,7 @@ func New(payloads map[string]interface{}, attackType AttackType, templatePath st
 			if err != nil {
 				return nil, errors.Wrap(err, "could not parse payloads with aggression")
 			}
-			for k, v := range values {
-				payloadsFinal[k] = v
-			}
+			maps.Copy(payloadsFinal, values)
 		default:
 			payloadsFinal[payloadName] = v
 		}
