@@ -3,6 +3,7 @@ package interactsh
 import (
 	"time"
 
+	"github.com/projectdiscovery/gologger"
 	"github.com/projectdiscovery/interactsh/pkg/client"
 	"github.com/projectdiscovery/nuclei/v3/pkg/fuzz/frequency"
 	"github.com/projectdiscovery/nuclei/v3/pkg/output"
@@ -46,6 +47,8 @@ type Options struct {
 	NoInteractsh bool
 	// NoColor disables printing colors for matches
 	NoColor bool
+	// Logger is the shared logging instance
+	Logger *gologger.Logger
 
 	FuzzParamsFrequency *frequency.Tracker
 	StopAtFirstMatch    bool
