@@ -6,6 +6,7 @@ import (
 	"encoding/hex"
 	"fmt"
 	"io"
+	"maps"
 	"os"
 	"path/filepath"
 	"strings"
@@ -66,8 +67,8 @@ func (request *Request) ExecuteWithResults(input *contextargs.Context, metadata,
 				return
 			}
 			defer func() {
-           _ = fi.Close()
-         }()
+				_ = fi.Close()
+			}()
 			format, stream, _ := archives.Identify(input.Context(), filePath, fi)
 			switch {
 			case format != nil:
@@ -86,8 +87,8 @@ func (request *Request) ExecuteWithResults(input *contextargs.Context, metadata,
 							return err
 						}
 						defer func() {
-              _ = reader.Close()
-            }()
+							_ = reader.Close()
+						}()
 						event, fileMatches, err := request.processReader(reader, archiveFileName, input, file.Size(), previous)
 						if err != nil {
 							if errors.Is(err, errEmptyResult) {
@@ -202,8 +203,8 @@ func (request *Request) processFile(filePath string, input *contextargs.Context,
 		return nil, nil, errors.Errorf("Could not open file path %s: %s\n", filePath, err)
 	}
 	defer func() {
-         _ = file.Close()
-       }()
+		_ = file.Close()
+	}()
 
 	stat, err := file.Stat()
 	if err != nil {
@@ -276,9 +277,7 @@ func (request *Request) findMatchesWithReader(reader io.Reader, input *contextar
 
 		gologger.Verbose().Msgf("[%s] Processing file %s chunk %s/%s", request.options.TemplateID, filePath, processedBytes, totalBytesString)
 		dslMap := request.responseToDSLMap(lineContent, input.MetaInput.Input, filePath)
-		for k, v := range previous {
-			dslMap[k] = v
-		}
+		maps.Copy(dslMap, previous)
 		// add vars to template context
 		request.options.AddTemplateVars(input.MetaInput, request.Type(), request.ID, dslMap)
 		// add template context variables to DSL map
@@ -347,9 +346,7 @@ func (request *Request) buildEvent(input, filePath string, fileMatches []FileMat
 	exprLines := make(map[string][]int)
 	exprBytes := make(map[string][]int)
 	internalEvent := request.responseToDSLMap("", input, filePath)
-	for k, v := range previous {
-		internalEvent[k] = v
-	}
+	maps.Copy(internalEvent, previous)
 	for _, fileMatch := range fileMatches {
 		exprLines[fileMatch.Expr] = append(exprLines[fileMatch.Expr], fileMatch.Line)
 		exprBytes[fileMatch.Expr] = append(exprBytes[fileMatch.Expr], fileMatch.ByteIndex)
