@@ -23,7 +23,6 @@ import (
 	"github.com/projectdiscovery/nuclei/v3/pkg/protocols/common/protocolstate"
 	contextutil "github.com/projectdiscovery/utils/context"
 	"github.com/projectdiscovery/utils/errkit"
-	errorutil "github.com/projectdiscovery/utils/errors"
 	fileutil "github.com/projectdiscovery/utils/file"
 	folderutil "github.com/projectdiscovery/utils/folder"
 	stringsutil "github.com/projectdiscovery/utils/strings"
@@ -32,8 +31,8 @@ import (
 )
 
 var (
-	errinvalidArguments = errorutil.New("invalid arguments provided")
-	ErrLFAccessDenied   = errorutil.New("Use -allow-local-file-access flag to enable local file access")
+	errinvalidArguments = errkit.New("invalid arguments provided").Build()
+	ErrLFAccessDenied   = errkit.New("Use -allow-local-file-access flag to enable local file access").Build()
 	// ErrActionExecDealine is the error returned when alloted time for action execution exceeds
 	ErrActionExecDealine = errkit.New("headless action execution deadline exceeded").SetKind(errkit.ErrKindDeadline).Build()
 )
@@ -60,7 +59,7 @@ func (p *Page) ExecuteActions(input *contextargs.Context, actions []*Action) (ou
 		}
 
 		if r := recover(); r != nil {
-			err = errorutil.New("panic on headless action: %v", r)
+			err = errkit.New(fmt.Sprintf("panic on headless action: %v", r)).Build()
 		}
 	}()
 
@@ -73,7 +72,7 @@ func (p *Page) ExecuteActions(input *contextargs.Context, actions []*Action) (ou
 				for _, waitFunc := range waitFuncs {
 					if waitFunc != nil {
 						if err := waitFunc(); err != nil {
-							return nil, errorutil.NewWithErr(err).Msgf("error occurred while executing waitFunc")
+							return nil, errkit.Append(errkit.New("error occurred while executing waitFunc"), err)
 						}
 					}
 				}
@@ -401,7 +400,7 @@ func (p *Page) NavigateURL(action *Action, out ActionData) error {
 
 	parsedURL, err := urlutil.ParseURL(url, true)
 	if err != nil {
-		return errorutil.NewWithTag("headless", "failed to parse url %v while creating http request", url)
+		return errkit.New(fmt.Sprintf("headless: failed to parse url %v while creating http request", url)).Build()
 	}
 
 	// ===== parameter automerge =====
@@ -411,7 +410,7 @@ func (p *Page) NavigateURL(action *Action, out ActionData) error {
 	parsedURL.Params = finalparams
 
 	if err := p.page.Navigate(parsedURL.String()); err != nil {
-		return errorutil.NewWithErr(err).Msgf("could not navigate to url %s", parsedURL.String())
+		return errkit.Append(errkit.New(fmt.Sprintf("could not navigate to url %s", parsedURL.String())), err)
 	}
 
 	p.updateLastNavigatedURL()
@@ -525,14 +524,14 @@ func (p *Page) Screenshot(act *Action, out ActionData) error {
 
 	to, err = fileutil.CleanPath(to)
 	if err != nil {
-		return errorutil.New("could not clean output screenshot path %s", to)
+		return errkit.New(fmt.Sprintf("could not clean output screenshot path %s", to)).Build()
 	}
 
 	// allow if targetPath is child of current working directory
-	if !protocolstate.IsLFAAllowed() {
+	if !protocolstate.IsLfaAllowed(p.options.Options) {
 		cwd, err := os.Getwd()
 		if err != nil {
-			return errorutil.NewWithErr(err).Msgf("could not get current working directory")
+			return errkit.Append(errkit.New("could not get current working directory"), err)
 		}
 
 		if !strings.HasPrefix(to, cwd) {
@@ -551,7 +550,7 @@ func (p *Page) Screenshot(act *Action, out ActionData) error {
 		// creates new directory if needed based on path `to`
 		// TODO: replace all permission bits with fileutil constants (https://github.com/projectdiscovery/utils/issues/113)
 		if err := os.MkdirAll(filepath.Dir(to), 0700); err != nil {
-			return errorutil.NewWithErr(err).Msgf("failed to create directory while writing screenshot")
+			return errkit.Append(errkit.New("failed to create directory while writing screenshot"), err)
 		}
 	}
 
@@ -563,7 +562,7 @@ func (p *Page) Screenshot(act *Action, out ActionData) error {
 
 	if fileutil.FileExists(filePath) {
 		// return custom error as overwriting files is not supported
-		return errorutil.NewWithTag("screenshot", "failed to write screenshot, file %v already exists", filePath)
+		return errkit.New(fmt.Sprintf("screenshot: failed to write screenshot, file %v already exists", filePath)).Build()
 	}
 	err = os.WriteFile(filePath, data, 0540)
 	if err != nil {
@@ -678,7 +677,7 @@ func (p *Page) WaitPageLifecycleEvent(act *Action, out ActionData, event proto.P
 
 // WaitStable waits until the page is stable
 func (p *Page) WaitStable(act *Action, out ActionData) error {
-	var dur = time.Second // default stable page duration: 1s
+	dur := time.Second // default stable page duration: 1s
 
 	timeout, err := getTimeout(p, act)
 	if err != nil {
@@ -806,12 +805,12 @@ func (p *Page) WaitEvent(act *Action, out ActionData) (func() error, error) {
 
 	gotType := proto.GetType(event)
 	if gotType == nil {
-		return nil, errorutil.New("event %q does not exist", event)
+		return nil, errkit.New(fmt.Sprintf("event %q does not exist", event)).Build()
 	}
 
 	tmp, ok := reflect.New(gotType).Interface().(proto.Event)
 	if !ok {
-		return nil, errorutil.New("event %q is not a page event", event)
+		return nil, errkit.New(fmt.Sprintf("event %q is not a page event", event)).Build()
 	}
 
 	waitEvent = tmp
@@ -948,7 +947,7 @@ func (p *Page) getActionArg(action *Action, arg string) (string, error) {
 
 	err = expressions.ContainsUnresolvedVariables(exprs...)
 	if err != nil {
-		return "", errorutil.NewWithErr(err).Msgf("argument %q, value: %q", arg, argValue)
+		return "", errkit.Append(errkit.New(fmt.Sprintf("argument %q, value: %q", arg, argValue)), err)
 	}
 
 	argValue, err = expressions.Evaluate(argValue, p.variables)
