@@ -22,6 +22,7 @@ import (
 	"github.com/projectdiscovery/nuclei/v3/pkg/protocols/common/protocolstate"
 	"github.com/projectdiscovery/nuclei/v3/pkg/testutils/testheadless"
 	"github.com/projectdiscovery/nuclei/v3/pkg/types"
+	envutil "github.com/projectdiscovery/utils/env"
 	stringsutil "github.com/projectdiscovery/utils/strings"
 )
 
@@ -643,8 +644,9 @@ func testHeadlessSimpleResponse(t *testing.T, response string, actions []*Action
 func testHeadless(t *testing.T, actions []*Action, timeout time.Duration, handler func(w http.ResponseWriter, r *http.Request), assert func(page *Page, pageErr error, extractedData ActionData)) {
 	t.Helper()
 
-	lfa := getBoolFromEnv("LOCAL_FILE_ACCESS", true)
-	rna := getBoolFromEnv("RESTRICED_LOCAL_NETWORK_ACCESS", false)
+	lfa := envutil.GetEnvOrDefault("LOCAL_FILE_ACCESS", true)
+	rna := envutil.GetEnvOrDefault("RESTRICED_LOCAL_NETWORK_ACCESS", false)
+
 	opts := &types.Options{AllowLocalFileAccess: lfa, RestrictLocalNetworkAccess: rna}
 
 	_ = protocolstate.Init(opts)
@@ -755,11 +757,3 @@ func TestBlockedHeadlessURLS(t *testing.T) {
 		}
 	}
 }
-
-func getBoolFromEnv(key string, defaultValue bool) bool {
-	val := os.Getenv(key)
-	if val == "" {
-		return defaultValue
-	}
-	return strings.EqualFold(val, "true")
-}
