@@ -110,7 +110,7 @@ func (p *Page) routingRuleHandlerNative(e *proto.FetchRequestPaused) error {
 	// ValidateNFailRequest validates if Local file access is enabled
 	// and local network access is enables if not it will fail the request
 	// that don't match the rules
-	if err := protocolstate.ValidateNFailRequest(p.page, e); err != nil {
+	if err := protocolstate.ValidateNFailRequest(p.options.Options, p.page, e); err != nil {
 		return err
 	}
 	body, _ := FetchGetResponseBody(p.page, e)
