@@ -31,7 +31,7 @@ import (
 	"github.com/projectdiscovery/nuclei/v3/pkg/reporting/trackers/gitlab"
 	"github.com/projectdiscovery/nuclei/v3/pkg/reporting/trackers/jira"
 	"github.com/projectdiscovery/nuclei/v3/pkg/reporting/trackers/linear"
-	errorutil "github.com/projectdiscovery/utils/errors"
+	"github.com/projectdiscovery/utils/errkit"
 	fileutil "github.com/projectdiscovery/utils/file"
 )
 
@@ -84,7 +84,7 @@ func New(options *Options, db string, doNotDedupe bool) (Client, error) {
 		options.GitHub.OmitRaw = options.OmitRaw
 		tracker, err := github.New(options.GitHub)
 		if err != nil {
-			return nil, errorutil.NewWithErr(err).Wrap(ErrReportingClientCreation)
+			return nil, errkit.Append(ErrReportingClientCreation, err)
 		}
 		client.trackers = append(client.trackers, tracker)
 	}
@@ -93,7 +93,7 @@ func New(options *Options, db string, doNotDedupe bool) (Client, error) {
 		options.GitLab.OmitRaw = options.OmitRaw
 		tracker, err := gitlab.New(options.GitLab)
 		if err != nil {
-			return nil, errorutil.NewWithErr(err).Wrap(ErrReportingClientCreation)
+			return nil, errkit.Append(ErrReportingClientCreation, err)
 		}
 		client.trackers = append(client.trackers, tracker)
 	}
@@ -102,7 +102,7 @@ func New(options *Options, db string, doNotDedupe bool) (Client, error) {
 		options.Gitea.OmitRaw = options.OmitRaw
 		tracker, err := gitea.New(options.Gitea)
 		if err != nil {
-			return nil, errorutil.NewWithErr(err).Wrap(ErrReportingClientCreation)
+			return nil, errkit.Append(ErrReportingClientCreation, err)
 		}
 		client.trackers = append(client.trackers, tracker)
 	}
@@ -111,7 +111,7 @@ func New(options *Options, db string, doNotDedupe bool) (Client, error) {
 		options.Jira.OmitRaw = options.OmitRaw
 		tracker, err := jira.New(options.Jira)
 		if err != nil {
-			return nil, errorutil.NewWithErr(err).Wrap(ErrReportingClientCreation)
+			return nil, errkit.Append(ErrReportingClientCreation, err)
 		}
 		client.trackers = append(client.trackers, tracker)
 	}
@@ -120,58 +120,60 @@ func New(options *Options, db string, doNotDedupe bool) (Client, error) {
 		options.Linear.OmitRaw = options.OmitRaw
 		tracker, err := linear.New(options.Linear)
 		if err != nil {
-			return nil, errorutil.NewWithErr(err).Wrap(ErrReportingClientCreation)
+			return nil, errkit.Append(ErrReportingClientCreation, err)
 		}
 		client.trackers = append(client.trackers, tracker)
 	}
 	if options.MarkdownExporter != nil {
 		exporter, err := markdown.New(options.MarkdownExporter)
 		if err != nil {
-			return nil, errorutil.NewWithErr(err).Wrap(ErrExportClientCreation)
+			return nil, errkit.Append(ErrExportClientCreation, err)
 		}
 		client.exporters = append(client.exporters, exporter)
 	}
 	if options.SarifExporter != nil {
 		exporter, err := sarif.New(options.SarifExporter)
 		if err != nil {
-			return nil, errorutil.NewWithErr(err).Wrap(ErrExportClientCreation)
+			return nil, errkit.Append(ErrExportClientCreation, err)
 		}
 		client.exporters = append(client.exporters, exporter)
 	}
 	if options.JSONExporter != nil {
 		exporter, err := json_exporter.New(options.JSONExporter)
 		if err != nil {
-			return nil, errorutil.NewWithErr(err).Wrap(ErrExportClientCreation)
+			return nil, errkit.Append(ErrExportClientCreation, err)
 		}
 		client.exporters = append(client.exporters, exporter)
 	}
 	if options.JSONLExporter != nil {
 		exporter, err := jsonl.New(options.JSONLExporter)
 		if err != nil {
-			return nil, errorutil.NewWithErr(err).Wrap(ErrExportClientCreation)
+			return nil, errkit.Append(ErrExportClientCreation, err)
 		}
 		client.exporters = append(client.exporters, exporter)
 	}
 	if options.ElasticsearchExporter != nil {
 		options.ElasticsearchExporter.HttpClient = options.HttpClient
+		options.ElasticsearchExporter.ExecutionId = options.ExecutionId
 		exporter, err := es.New(options.ElasticsearchExporter)
 		if err != nil {
-			return nil, errorutil.NewWithErr(err).Wrap(ErrExportClientCreation)
+			return nil, errkit.Append(ErrExportClientCreation, err)
 		}
 		client.exporters = append(client.exporters, exporter)
 	}
 	if options.SplunkExporter != nil {
 		options.SplunkExporter.HttpClient = options.HttpClient
+		options.SplunkExporter.ExecutionId = options.ExecutionId
 		exporter, err := splunk.New(options.SplunkExporter)
 		if err != nil {
-			return nil, errorutil.NewWithErr(err).Wrap(ErrExportClientCreation)
+			return nil, errkit.Append(ErrExportClientCreation, err)
 		}
 		client.exporters = append(client.exporters, exporter)
 	}
 	if options.MongoDBExporter != nil {
 		exporter, err := mongo.New(options.MongoDBExporter)
 		if err != nil {
-			return nil, errorutil.NewWithErr(err).Wrap(ErrExportClientCreation)
+			return nil, errkit.Append(ErrExportClientCreation, err)
 		}
 		client.exporters = append(client.exporters, exporter)
 	}
@@ -225,11 +227,11 @@ func CreateConfigIfNotExists() error {
 	}
 	reportingFile, err := os.Create(reportingConfig)
 	if err != nil {
-		return errorutil.NewWithErr(err).Msgf("could not create config file")
+		return errkit.Append(errkit.New("could not create config file"), err)
 	}
 	defer func() {
-         _ = reportingFile.Close()
-       }()
+		_ = reportingFile.Close()
+	}()
 
 	err = yaml.NewEncoder(reportingFile).Encode(options)
 	return err
