@@ -1,10 +1,10 @@
 package templates
 
 import (
-	"encoding/json"
 	"os"
 	"testing"
 
+	"github.com/projectdiscovery/nuclei/v3/pkg/utils/json"
 	"github.com/stretchr/testify/require"
 	"gopkg.in/yaml.v2"
 )
